summaryrefslogtreecommitdiffstats
path: root/src/UiGuiSettings.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/UiGuiSettings.h')
-rwxr-xr-xsrc/UiGuiSettings.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/src/UiGuiSettings.h b/src/UiGuiSettings.h
index c818199..c9e5917 100755
--- a/src/UiGuiSettings.h
+++ b/src/UiGuiSettings.h
@@ -20,44 +20,44 @@
#ifndef UIGUISETTINGS_H
#define UIGUISETTINGS_H
-#include <tqobject.h>
-#include <tqstringlist.h>
+#include <tntqobject.h>
+#include <tntqstringlist.h>
#include <tqmultimap.h>
#include <tqsharedpointer.h>
-class QSettings;
+class TQSettings;
-class UiGuiSettings : public QObject
+class UiGuiSettings : public TQObject
{
Q_OBJECT
private:
UiGuiSettings();
- static QWeakPointer<UiGuiSettings> _instance;
+ static TQWeakPointer<UiGuiSettings> _instance;
public:
- static QSharedPointer<UiGuiSettings> getInstance();
+ static TQSharedPointer<UiGuiSettings> getInstance();
~UiGuiSettings();
- bool registerObjectProperty(QObject *obj, const QString &propertyName, const QString &settingName);
- bool registerObjectPropertyRecursive(QObject *obj);
- bool setObjectPropertyToSettingValue(QObject *obj, const QString &propertyName, const QString &settingName);
- bool setObjectPropertyToSettingValueRecursive(QObject *obj);
- bool setSettingToObjectPropertyValue(QObject *obj, const QString &propertyName, const QString &settingName);
- bool setSettingToObjectPropertyValueRecursive(QObject *obj);
- bool registerObjectSlot(QObject *obj, const QString &slotName, const QString &settingName);
- QVariant getValueByName(QString settingName);
- QStringList getAvailableTranslations();
+ bool registerObjectProperty(TQObject *obj, const TQString &propertyName, const TQString &settingName);
+ bool registerObjectPropertyRecursive(TQObject *obj);
+ bool setObjectPropertyToSettingValue(TQObject *obj, const TQString &propertyName, const TQString &settingName);
+ bool setObjectPropertyToSettingValueRecursive(TQObject *obj);
+ bool setSettingToObjectPropertyValue(TQObject *obj, const TQString &propertyName, const TQString &settingName);
+ bool setSettingToObjectPropertyValueRecursive(TQObject *obj);
+ bool registerObjectSlot(TQObject *obj, const TQString &slotName, const TQString &settingName);
+ TQVariant getValueByName(TQString settingName);
+ TQStringList getAvailableTranslations();
public slots:
- void setValueByName(const QString &settingName, const QVariant &value);
- void unregisterObjectProperty(QObject *obj);
- void unregisterObjectSlot(QObject *obj, const QString &slotName = "", const QString &settingName = "");
+ void setValueByName(const TQString &settingName, const TQVariant &value);
+ void unregisterObjectProperty(TQObject *obj);
+ void unregisterObjectSlot(TQObject *obj, const TQString &slotName = "", const TQString &settingName = "");
protected:
bool initSettings();
- bool invokeMethodWithValue(QObject *obj, QMetaMethod mMethod, QVariant value);
- bool checkCustomPropertiesAndCallFunction(QObject *obj, bool (UiGuiSettings::*callBackFunc)(QObject *obj, const QString &propertyName, const QString &settingName));
+ bool invokeMethodWithValue(TQObject *obj, TQMetaMethod mMethod, TQVariant value);
+ bool checkCustomPropertiesAndCallFunction(TQObject *obj, bool (UiGuiSettings::*callBackFunc)(TQObject *obj, const TQString &propertyName, const TQString &settingName));
private slots:
void handleObjectPropertyChange();
@@ -66,18 +66,18 @@ private:
void readAvailableTranslations();
//! Stores the mnemonics of the available translations.
- QStringList _availableTranslations;
+ TQStringList _availableTranslations;
//! The settings file.
- QSettings *_qsettings;
+ TQSettings *_qsettings;
- //! Maps an QObject to a string list containing the property name and the associated setting name.
- QMap<QObject*, QStringList> _registeredObjectProperties;
+ //! Maps an TQObject to a string list containing the property name and the associated setting name.
+ TQMap<TQObject*, TQStringList> _registeredObjectProperties;
- //! Maps QObjects to a string list containing the method name and the associated setting name.
- QMultiMap<QObject*, QStringList> _registeredObjectSlots;
+ //! Maps TQObjects to a string list containing the method name and the associated setting name.
+ TQMultiMap<TQObject*, TQStringList> _registeredObjectSlots;
- QString _indenterDirctoryStr;
+ TQString _indenterDirctoryStr;
};
#endif // UIGUISETTINGS_H